package com.ghy.order.mapper;

import java.util.List;
import com.ghy.order.domain.OrderAttachmentRecord;
import org.apache.ibatis.annotations.Param;

/**
 * 附件费Mapper接口
 *
 * @author clunt
 * @date 2024-01-02
 */
public interface OrderAttachmentRecordMapper
{
    /**
     * 查询附件费
     *
     * @param id 附件费主键
     * @return 附件费
     */
    public OrderAttachmentRecord selectOrderAttachmentRecordById(Long id);

    /**
     * 查询附件费列表
     *
     * @param orderAttachmentRecord 附件费
     * @return 附件费集合
     */
    public List<OrderAttachmentRecord> selectOrderAttachmentRecordList(OrderAttachmentRecord orderAttachmentRecord);

    /**
     * 新增附件费
     *
     * @param orderAttachmentRecord 附件费
     * @return 结果
     */
    public int insertOrderAttachmentRecord(OrderAttachmentRecord orderAttachmentRecord);

    /**
     * 修改附件费
     *
     * @param orderAttachmentRecord 附件费
     * @return 结果
     */
    public int updateOrderAttachmentRecord(OrderAttachmentRecord orderAttachmentRecord);

    /**
     * 删除附件费
     *
     * @param id 附件费主键
     * @return 结果
     */
    public int deleteOrderAttachmentRecordById(Long id);

    /**
     * 批量删除附件费
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderAttachmentRecordByIds(String[] ids);


    /**
     * 删除附件费 根据子单id
     *
     * @param id 子单id
     * @return 结果
     */
    public int deleteOrderAttachmentRecordByOrderDetailId(Long orderDetailId);
}
